<?php
/** Gothic (Gothic)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Jocke Pirat
 * @author Michawiki
 * @author Node ue
 * @author Sajasazi (on got.wikipedia.org)
 * @author Zylbath
 */

$messages = array(
'underline-always' => 'Sinteino',
'underline-never'  => 'Niu',

# Dates
'sunday'        => 'Sunnonsdags',
'monday'        => 'Meninsdags',
'tuesday'       => 'Tiwisdags',
'wednesday'     => 'Midiwiko',
'thursday'      => 'Þeiƕonsdags',
'friday'        => 'Fraujonsdags',
'saturday'      => '𐌸𐍅𐌰𐌷𐌻𐌹𐍃𐌳𐌰𐌲𐍃',
'sun'           => 'Sun',
'mon'           => 'Men',
'tue'           => 'Tiw',
'wed'           => 'Mid',
'thu'           => 'Þei',
'fri'           => 'Fra',
'sat'           => 'Þwa',
'january'       => '𐌰𐍆𐍄𐌿𐌼𐌰 𐌾𐌹𐌿𐌻𐌴𐌹𐍃',
'february'      => '𐍆𐌰𐌽𐌹𐌼𐌴𐌽𐍉𐌸𐍃',
'march'         => '𐌺𐌰𐌻𐌳𐌼𐌴𐌽𐍉𐌸𐍃',
'april'         => '𐌲𐍂𐌰𐍃𐌼𐌴𐌽𐍉𐌸𐍃',
'may_long'      => '𐌱𐌻𐍉𐌼𐌰𐌼𐌴𐌽𐍉𐌸𐍃',
'june'          => '𐍅𐌰𐍂𐌼𐌼𐌴𐌽𐍉𐌸𐍃',
'july'          => '𐌷𐌰𐍅𐌹𐌼𐌴𐌽𐍉𐌸𐍃',
'august'        => '𐌰𐍃𐌰𐌽𐌼𐌴𐌽𐍉𐌸𐍃',
'september'     => '𐌰𐌺𐍂𐌰𐌽𐌼𐌴𐌽𐍉𐌸𐍃',
'october'       => '𐍅𐌴𐌹𐌽𐌼𐌴𐌽𐍉𐌸𐍃',
'november'      => '𐍆𐍂𐌿𐌼𐌰 𐌾𐌹𐌿𐌻𐌴𐌹𐍃',
'december'      => '𐌾𐌹𐌿𐌻𐌴𐌹𐍃',
'january-gen'   => '𐌰𐍆𐍄𐌿𐌼𐌹𐌽𐍃 𐌾𐌹𐌿𐌻𐌴𐌹𐍃',
'february-gen'  => '𐍆𐌰𐌽𐌹𐌼𐌴𐌽𐍉𐌸𐌹𐍃',
'march-gen'     => 'Kaldmenoþis',
'april-gen'     => '𐌲𐍂𐌰𐍃𐌼𐌴𐌽𐍉𐌸𐌹𐍃',
'may-gen'       => '𐌱𐌻𐍉𐌼𐌰𐌼𐌴𐌽𐍉𐌸𐌹𐍃',
'june-gen'      => 'Warmmenoþis',
'july-gen'      => 'Hawimenoþis',
'august-gen'    => '𐌰𐍃𐌰𐌽𐌼𐌴𐌽𐍉𐌸𐌹𐍃',
'september-gen' => '𐌰𐌺𐍂𐌰𐌽𐌼𐌴𐌽𐍉𐌸𐌹𐍃',
'october-gen'   => '𐍅𐌴𐌹𐌽𐌼𐌴𐌽𐍉𐌸𐌹𐍃',
'november-gen'  => '𐍆𐍂𐌿𐌼𐌹𐌽𐍃 𐌾𐌹𐌿𐌻𐌴𐌹𐍃',
'december-gen'  => '𐌾𐌹𐌿𐌻𐌴𐌹𐍃',
'jan'           => '𐌰𐍆𐍄',
'feb'           => 'Fan',
'mar'           => 'Kal',
'apr'           => '𐌲𐍂𐌰',
'may'           => '𐌱𐌻𐍉',
'jun'           => 'War',
'jul'           => 'Haw',
'aug'           => '𐌰𐍃𐌰',
'sep'           => '𐌰𐌺𐍂',
'oct'           => '𐍅𐌴𐌹',
'nov'           => '𐍆𐍂𐌿',
'dec'           => '𐌾𐌹𐌿',

# Categories related messages
'pagecategories'        => '{{PLURAL:$1|𐌺𐌿𐌽𐌾𐌰|𐌺𐌿𐌽𐌾𐍉𐍃}}',
'category_header'       => '𐍃𐌴𐌹𐌳𐍉𐍃 𐌹𐌽𐌽 𐌺𐌿𐌽𐌾𐌰 "$1"',
'subcategories'         => 'Dalaþkunjos',
'category-media-header' => '𐌼𐌴𐌳𐌾𐌰 𐌹𐌽𐌽 𐌺𐌿𐌽𐌾𐌰 "$1"',

'about'         => '𐌿𐍆𐌰𐍂',
'article'       => '𐍃𐌰𐌸𐍃𐍃𐌴𐌹𐌳𐍉',
'newwindow'     => '(𐌰𐌽𐌳𐌷𐌿𐌻𐌾𐌹𐌸 𐌹𐌽𐌽 𐌽𐌹𐌿𐌾𐌰 𐌰𐌿𐌲𐌰𐌳𐌰𐌿𐍂𐍉)',
'cancel'        => '𐌷𐌰𐌻𐍄𐍃',
'moredotdotdot' => '𐌼𐌰𐌹𐍃...',
'mypage'        => '𐌼𐌴𐌹𐌽 𐍃𐌴𐌹𐌳𐍉',
'mytalk'        => '𐌼𐌴𐌹𐌽𐌰 𐌼𐌰𐌸𐌻𐌴𐌹',
'navigation'    => '𐍃𐌴𐌹𐌳𐍉𐌲𐌰𐍅𐌹𐍃𐍃',
'and'           => '𐌾𐌰𐌷',

# Cologne Blue skin
'qbfind'         => '𐍃𐍉𐌺𐌴𐌹𐌸',
'qbedit'         => '𐌼𐌰𐌹𐌳𐌾𐌰𐌽',
'qbmyoptions'    => '𐌼𐌴𐌹𐌽𐌰 𐍃𐌴𐌹𐌳𐍉𐍃',
'qbspecialpages' => '𐌿𐍃𐍃𐌹𐌽𐌳𐍃𐌴𐌹𐌳𐍉𐍃',

# Vector skin
'vector-action-delete' => '𐍄𐌰𐌹𐍂𐌰𐌽',
'vector-view-create'   => 'Skapjan',
'vector-view-edit'     => 'Máidjan',
'vector-view-view'     => 'Lisan',

'errorpagetitle'    => '𐍆𐌰𐌹𐍂𐌹𐌽𐌰 𐌳𐍅𐌰𐌻𐌹𐍃',
'returnto'          => '𐌲𐌰𐍅𐌰𐌽𐌳𐌾𐌰𐌽 𐌰𐍄 $1.',
'tagline'           => 'Fram {{SITENAME}}',
'help'              => '𐌷𐌹𐌻𐍀𐌰',
'search'            => '𐍃𐍉𐌺𐌴𐌹𐌸',
'searchbutton'      => '𐍃𐍉𐌺𐌴𐌹𐌸',
'go'                => '𐌲𐌰𐌲𐌲𐌰',
'searcharticle'     => '𐌰𐍆𐌲𐌰𐌲𐌲𐌰𐌽',
'history'           => '𐌰𐌹𐍂𐌹𐍃 𐌼𐌰𐌹𐌳𐌴𐌹𐌽𐍃 𐌰𐌽𐌰 𐍃𐌴𐌹𐌳𐍉',
'history_short'     => '𐌰𐌹𐍂𐌹𐍃 𐌼𐌰𐌹𐌳𐌴𐌹𐌽𐍃',
'printableversion'  => '𐌳𐍂𐌹𐌿𐍃𐌰𐌽 𐍃𐌴𐌹𐌳𐍉',
'permalink'         => '𐌰𐍅𐌴𐌹𐌽𐍃 𐍄𐌰𐌹𐌺𐌽𐌾𐌰𐌱𐌰𐌽𐌳𐌹',
'view'              => 'Saíhvan',
'edit'              => '𐌼𐌰𐌹𐌳𐌾𐌰𐌽',
'create'            => 'Skapjan',
'editthispage'      => '𐌼𐌰𐌹𐌳𐌾𐌰 𐌸𐍉 𐍃𐌴𐌹𐌳𐍉',
'create-this-page'  => 'Skapja þo seido',
'delete'            => '𐍄𐌰𐌹𐍂𐌰𐌽',
'deletethispage'    => '𐍄𐌰𐌹𐍂𐌰 𐌸𐍉 𐍃𐌴𐌹𐌳𐍉',
'protect'           => '𐌱𐌰𐌹𐍂𐌲𐌰𐌽',
'protectthispage'   => 'Baírga þo siedo',
'unprotect'         => '𐌽𐌹𐌱𐌰𐌹𐍂𐌲𐌰',
'unprotectthispage' => 'Nibaírga þo siedo',
'newpage'           => '𐌽𐌹𐌿𐌾𐌰 𐍃𐌴𐌹𐌳𐍉',
'talkpage'          => '𐌼𐌰𐌸𐌻𐌴𐌹𐍃𐌴𐌹𐌳𐍉',
'talkpagelinktext'  => '𐌼𐌰𐌸𐌻𐌴𐌹𐍃𐌴𐌹𐌳𐍉',
'specialpage'       => '𐌿𐍃𐍃𐌹𐌽𐌳𐍃𐌴𐌹𐌳𐍉𐍃',
'personaltools'     => '𐍅𐌰𐌹𐍂𐌻𐌴𐌹𐌺𐍃 𐌱𐍂𐌿𐌺𐍅𐌰𐌹𐌷𐍄𐍃',
'talk'              => '𐌲𐌰𐍅𐌰𐌿𐍂𐌳𐌾𐌰',
'views'             => '𐍃𐌹𐌿𐌽𐌴𐌹𐍃',
'toolbox'           => '𐍄𐌰𐌿𐌹 𐌰𐍂𐌺𐌰',
'otherlanguages'    => '𐌰𐌽𐌸𐌰𐍂 𐍂𐌰𐌶𐌳𐍉𐍃',
'redirectedfrom'    => '(Náuþjan framis $1)',
'redirectpagesub'   => '𐍄𐌰𐌹𐌺𐌾𐌰𐍃𐌴𐌹𐌳𐍉',
'jumpto'            => 'Gaggan at:',
'jumptonavigation'  => '𐍃𐌴𐌹𐌳𐍉𐌲𐌰𐍅𐌹𐍃𐍃',
'jumptosearch'      => 'sokeiþ',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => '𐍆𐍂𐌰𐌼 {{SITENAME}}',
'aboutpage'            => 'Project:𐌿𐍆𐌰𐍂',
'copyrightpage'        => '{{ns:project}}:Manleikawitoþa',
'currentevents'        => 'Niuja waíhts',
'currentevents-url'    => 'Project:𐌽𐌹𐌿𐌾𐌰 𐍅𐌰𐌹𐌷𐍄𐍃',
'disclaimers'          => '𐌰𐍆𐌰𐌹𐌺𐌰𐌽 𐍅𐌹𐍄𐍉𐌸',
'disclaimerpage'       => 'Project:𐌰𐍆𐌰𐌹𐌺𐌰𐌽 𐍅𐌹𐍄𐍉𐌸',
'edithelp'             => '𐌼𐌰𐌹𐌳𐌴𐌹𐌽𐌹𐌷𐌹𐌻𐍀𐌰',
'edithelppage'         => 'Help:𐌼𐌰𐌹𐌳𐌾𐌰',
'helppage'             => 'Hilpa:Háubidaseido',
'mainpage'             => '𐌷𐌰𐌿𐌱𐌹𐌳𐌰𐍃𐌴𐌹𐌳𐍉',
'mainpage-description' => '𐌷𐌰𐌿𐌱𐌹𐌳𐌰𐍃𐌴𐌹𐌳𐍉',
'portal'               => '𐌱𐌰𐌿𐍂𐌲𐍃 𐌲𐌰𐍅𐌹',
'portal-url'           => 'Project:𐌱𐌰𐌿𐍂𐌲𐍃 𐌲𐌰𐍅𐌹',
'privacy'              => '𐌰𐌽𐌰𐍃𐌹𐌻𐌰 𐍅𐌹𐍄𐍉𐌸',
'privacypage'          => 'Project:𐌰𐌽𐌰𐍃𐌹𐌻𐌰 𐍅𐌹𐍄𐍉𐌸',

'retrievedfrom'       => 'Niman fram "$1"',
'youhavenewmessages'  => '𐌸𐌿 𐌷𐌰𐌱𐌹𐍃 $1 ($2).',
'newmessageslink'     => '𐌽𐌹𐌿𐌾𐍉 𐌼𐌰𐌸𐌻𐌴𐌹',
'newmessagesdifflink' => '𐍃𐍀𐌴𐌳𐌿𐌼𐌹𐍃𐍄𐍃 𐌼𐌰𐌹𐌳𐌴𐌹𐌽𐍃',
'editsection'         => '𐌼𐌰𐌹𐌳𐌾𐌰𐌽',
'editold'             => '𐌼𐌰𐌹𐌳𐌾𐌰𐌽',
'editlink'            => 'máidjan',
'editsectionhint'     => '𐌼𐌰𐌹𐌳𐌾𐌰𐌽 𐌰𐍆 𐍆𐌴𐍂𐌰: $1',
'toc'                 => '𐌹𐌽𐌽𐌰𐌽𐌰',
'showtoc'             => '𐌰𐌿𐌲𐌾𐌰',
'hidetoc'             => '𐍆𐌹𐌻𐌷𐌰𐌽',
'site-rss-feed'       => '$1 RSS Miþnatifodjan',
'site-atom-feed'      => '$1 Atom Miþnatifodjan',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'     => '𐍃𐌴𐌹𐌳𐍉',
'nstab-user'     => '𐌽𐌹𐌿𐍄𐌰𐌽𐌳𐌹𐍃𐍃𐌴𐌹𐌳𐍉',
'nstab-special'  => '𐌿𐍃𐍃𐌹𐌽𐌳𐍃𐌴𐌹𐌳𐍉',
'nstab-project'  => '𐍂𐌴𐌹𐌺𐌹𐍃𐌴𐌹𐌳𐍉',
'nstab-image'    => '𐌼𐌰𐌽𐌻𐌴𐌹𐌺𐌰',
'nstab-template' => '𐌼𐌰𐍂𐌺𐌰',
'nstab-help'     => '𐌷𐌹𐌻𐍀𐌰',
'nstab-category' => '𐌺𐌿𐌽𐌾𐌰',

# General errors
'viewsource' => '𐍃𐌰𐌹𐍈𐌰 𐌹𐌽𐌽𐌰𐌽𐌰',

# Login and logout pages
'yourname'                => '𐌽𐌹𐌿𐍄𐌰𐌽𐌳𐌹𐍃𐌽𐌰𐌼𐍉:',
'yourpassword'            => '𐌰𐌽𐌰𐌻𐌰𐌿𐌲𐌽𐍃 𐍅𐌰𐌿𐍂𐌳𐌰:',
'login'                   => 'Atgaggan',
'nav-login-createaccount' => '𐌰𐍄𐌲𐌰𐌲𐌲𐌰𐌽 / 𐌲𐌰𐌻𐌰𐌽𐌲𐌾𐌰𐌽 𐌽𐌹𐌿𐍄𐌰𐌽𐌳𐌹𐍃',
'userlogin'               => 'Atgaggan / gaskapjan niutandis',
'logout'                  => '𐌻𐌴𐌹𐌸𐌰𐌽',
'userlogout'              => '𐌻𐌴𐌹𐌸𐌰𐌽',
'nologinlink'             => 'Gaskapjan þein niutandis',
'createaccount'           => '𐌲𐌰𐌻𐌰𐌲𐌾𐌰𐌽 𐌽𐌹𐌿𐍄𐌰𐌽𐌳𐌹𐍃',
'gotaccount'              => "Habiþ þu niutandis? '''$1'''",
'gotaccountlink'          => 'Atgaggan',
'loginlanguagelabel'      => 'Razda: $1',

# Edit page toolbar
'bold_sample'     => '𐌰𐌱𐍂𐍃 𐌱𐍉𐌺𐌰',
'bold_tip'        => '𐌰𐌱𐍂 𐍅𐌰𐌿𐍂𐌳𐌰',
'italic_sample'   => 'Wráiqs waúrda',
'italic_tip'      => 'Driuso boka',
'link_sample'     => 'Táikjanbandi namo',
'link_tip'        => 'táikjanbandi innana',
'extlink_sample'  => 'http://www.example.com Táikjandandi namo',
'extlink_tip'     => 'Uta táikjabandi (maúdjan http://)',
'headline_sample' => 'Háubidawaúrda',
'headline_tip'    => 'Háuhs háubidaboka 2',
'media_tip'       => 'Táikjabandjis feilanis',
'hr_tip'          => 'Ráihtsbáurd (brukjan miþ niufarussus)',

# Edit pages
'summary'                => '𐌼𐌰𐌹𐌳𐌾𐌰𐌽𐍃𐍀𐌹𐌻𐌻𐍉𐌽:',
'subject'                => '𐌷𐌰𐌿𐌱𐌹𐌳𐌰𐌱𐍉𐌺𐌰:',
'minoredit'              => '𐍃𐌰 𐌹𐍃𐍄 𐌻𐌴𐌹𐍄𐌹𐌻𐌰 𐌼𐌰𐌹𐌳𐌴𐌹𐌽𐍃',
'watchthis'              => '𐍅𐌰𐍂𐌰𐌽 𐍃𐌴𐌹𐌳𐍉',
'savearticle'            => '𐌼𐌴𐌻𐌾𐌰 𐍃𐌴𐌹𐌳𐍉',
'preview'                => '𐍆𐌰𐌿𐍂𐍃𐌰𐌹𐍈𐌰 𐍃𐌴𐌹𐌳𐍉',
'showpreview'            => '𐍅𐌹𐍄𐌰𐌽 𐍆𐌰𐌿𐍂𐍃𐌰𐌹𐍈𐌰',
'showdiff'               => '𐍅𐌹𐍄𐌰𐌽 𐌼𐌰𐌹𐌳𐌴𐌹𐌽𐍃',
'newarticle'             => '(Niu)',
'updated'                => '(Nuwisan)',
'previewnote'            => "'''𐍃𐌰𐌷 𐌹𐍃𐍄 𐍆𐌰𐌿𐍂𐍃𐌰𐌹𐍈𐌰. 𐌼𐌰𐌹𐌳𐌴𐌹𐌽𐍃 𐌲𐌰𐌼𐌴𐌻𐌾𐌹𐌸 𐌽𐌹 𐌰𐍆 𐌸𐌹𐌶𐍉𐍃 𐍃𐌴𐌹𐌳𐍉𐍃!'''",
'editing'                => '𐌼𐌰𐌹𐌳𐌾𐌰𐌽 𐌰𐍆 $1',
'editingsection'         => '𐌼𐌰𐌹𐌳𐌾𐌰𐌽 𐌰𐍆 $1 (𐍆𐌴𐍂𐌰)',
'editingcomment'         => '𐌼𐌰𐌹𐌳𐌾𐌰𐌽 𐌰𐍆 $1 (𐍂𐍉𐌳𐌾𐌰𐍆𐌴𐍂𐌰)',
'yourdiff'               => 'Missalieks',
'template-protected'     => '(gabaírgan)',
'template-semiprotected' => '(halb-gabaírgjan)',

# History pages
'currentrev'          => '𐌽𐌿 𐌼𐌰𐌹𐌳𐌴𐌹𐌽𐍃',
'revisionasof'        => '𐌲𐌰𐌼𐌴𐌻𐌹𐌳𐍉 𐌿𐍃 $1',
'revision-info'       => 'Máideins fram $1 bi $2',
'previousrevision'    => '←𐌰𐌹𐍂𐌹𐍃 𐌼𐌰𐌹𐌳𐌴𐌹𐌽𐍃',
'nextrevision'        => 'Iftuma máideins→',
'currentrevisionlink' => '𐌽𐌿𐌼𐌰𐌹𐌳𐌴𐌹𐌽𐍃',
'cur'                 => '𐌽𐌿',
'next'                => '𐌹𐍆𐍄𐌿𐌼𐌰',
'last'                => '𐌰𐍆𐍄𐌿𐌼𐌹𐍃𐍄𐍃',
'page_first'          => 'frumists',
'page_last'           => '𐍃𐍀𐌴𐌳𐌿𐌼𐌹𐍃𐍄𐍃',
'histfirst'           => '𐍆𐌰𐌿𐍂𐌸𐌹𐍃',
'histlast'            => '𐍃𐍀𐌴𐌳𐌿𐌼𐌹𐍃𐍄𐍃',

# Revision feed
'history-feed-item-nocomment' => '$1 at $2',

# Diffs
'history-title' => '𐌰𐍂𐌹𐍃𐌼𐌰𐌹𐌳𐌴𐌹𐌽𐍃 𐌰𐍆 "$1"',
'lineno'        => '𐌱𐍉𐌺𐌰𐍂𐌹𐌲𐌹𐌻𐍉 $1:',
'editundo'      => '𐌽𐌹𐌿𐍃𐌺𐌰𐍀𐌾𐌰𐌽',

# Search results
'prevn'              => 'aftuma {{PLURAL:$1|$1}}',
'nextn'              => 'iftuma {{PLURAL:$1|$1}}',
'viewprevnext'       => '𐍃𐌹𐌿𐌽𐌴𐌹𐍃 ($1 {{int:pipe-separator}} $2) ($3)',
'searchhelp-url'     => 'Hilpa:Háubidaseido',
'powersearch'        => 'Sokeiþ',
'powersearch-legend' => '𐍃𐍉𐌺𐌴𐌹𐌸',
'powersearch-redir'  => '𐍄𐌰𐌻𐌰 𐌰𐍆 𐍄𐌰𐌹𐌺𐌾𐌰𐌽𐍃𐌴𐌹𐌳𐍉𐍃',

# Preferences page
'preferences'       => '𐌼𐌴𐌹𐌽𐍉𐍃 𐌱𐍂𐌿𐌺𐌾𐌰𐌼𐌰𐌹𐌳𐌴𐌹𐌽𐌴𐌹𐍃',
'mypreferences'     => '𐌼𐌴𐌹𐌽𐍉𐍃 𐌱𐍂𐌿𐌺𐌾𐌰',
'prefs-skin'        => 'Seidofill',
'skin-preview'      => 'Faúrsaiƕa',
'saveprefs'         => 'Melja',
'searchresultshead' => 'Sokeiþ',

'grouppage-sysop' => '{{ns:project}}:𐍃𐌴𐌹𐌳𐍉𐍆𐌰𐌸𐍃',

# User rights log
'rightslog'  => 'Niutandis stutjanlog',
'rightsnone' => '(ni áinshun)',

# Recent changes
'nchanges'        => '$1 {{PLURAL:$1|máidein|máideins}}',
'recentchanges'   => '𐌰𐍆𐍄𐌿𐌼𐌹𐍃𐍄𐍉𐍃 𐌼𐌰𐌹𐌳𐌴𐌹𐌽𐌴𐌹𐍃',
'rcshowhideminor' => '$1 lietila máideins',
'rcshowhidebots'  => '$1 bota',
'rcshowhideliu'   => '$1 niutandis',
'rcshowhideanons' => '$1 gasteis',
'rcshowhidemine'  => '$1 mein máideins',
'diff'            => '𐌻𐌴𐌹𐌺𐍃',
'hist'            => '𐌰𐌹𐍂𐌹𐍃',
'hide'            => 'Filhan',
'show'            => 'Huljan',
'minoreditletter' => 'l',
'newpageletter'   => 'N',
'boteditletter'   => 'b',

# Recent changes linked
'recentchangeslinked'         => '𐌼𐌰𐌹𐌳𐌴𐌹𐌽𐌻𐌹𐌴𐌺𐍃',
'recentchangeslinked-feed'    => 'Máideinlieks',
'recentchangeslinked-toolbox' => '𐌼𐌰𐌹𐌳𐌴𐌹𐌽𐌻𐌹𐌴𐌺𐍃',

# Upload
'upload'          => '𐌿𐍃𐌷𐌻𐌰𐌸𐌰𐌹𐌸 𐍆𐌴𐌹𐌻𐌰𐌽𐍃',
'uploadbtn'       => 'Ushlaþaiþ Feilans',
'uploadlogpage'   => 'Log af Ushlaþan',
'uploadedimage'   => 'ushlaþiþ "[[$1]]"',
'watchthisupload' => 'Witan so seido',

# Special:ListFiles
'imgfile'   => 'Feilans',
'listfiles' => 'Feilans tala',

# File description page
'file-anchor-link'    => 'Feilans',
'filehist'            => 'Feilans áiris',
'filehist-current'    => 'nu',
'filehist-datetime'   => 'Ƕeila',
'filehist-user'       => 'Niutandis',
'filehist-dimensions' => 'Wahstus',
'filehist-filesize'   => 'Feilans wahstus',
'filehist-comment'    => 'Leitilaspillon',
'imagelinks'          => 'Táiknjabandja',

# File deletion
'filedelete-submit' => 'Taíran',

# MIME search
'mimesearch' => 'MIME sokeiþ',

# List redirects
'listredirects' => '𐍄𐌰𐌻𐌰 𐌰𐍆 𐍄𐌰𐌹𐌺𐌾𐌰𐌽𐍃𐌴𐌹𐌳𐍉𐍃',

# Random page
'randompage' => '𐍃𐌻𐌿𐌼𐍀𐌼𐌰𐍃𐍃𐌹𐌲 𐍃𐌴𐌹𐌳𐍉',

# Statistics
'statistics' => '𐍃𐌴𐌹𐌳𐍉𐍃𐍄𐌰𐍄𐌹𐍃𐍄𐌹𐌺',

'brokenredirects-edit'   => '(𐌼𐌰𐌹𐌳𐌾𐌰𐌽)',
'brokenredirects-delete' => '(𐍄𐌰𐌹𐍂𐌰𐌽)',

# Miscellaneous special pages
'nbytes'       => '$1 {{PLURAL:$1|𐌱𐌰𐌹𐍄|𐌱𐌰𐌹𐍄𐌰}}',
'ncategories'  => '$1 {{PLURAL:$1|𐌺𐌿𐌽𐌾𐌰|𐌺𐌿𐌽𐌾𐍉𐍃}}',
'nlinks'       => '$1 {{PLURAL:$1|táikjanbandi|táikjanbandja}}',
'nmembers'     => '$1 {{PLURAL:$1|niutand|niutanda}}',
'wantedpages'  => 'Gaírnedum seidam',
'shortpages'   => '𐌻𐌴𐌹𐍄𐌹𐌻𐌰 𐍃𐌴𐌹𐌳𐍉𐍃',
'longpages'    => '𐌻𐌰𐌲𐌲𐌰 𐍃𐌴𐌹𐌳𐍉𐍃',
'listusers'    => '𐍂𐌴𐌲𐌹𐍃𐍄𐍂𐌴𐍂𐌰𐌳𐌴 𐌱𐍂𐌿𐌺𐌾𐌰𐌽𐌳𐍃',
'newpages'     => '𐌽𐌹𐌿𐌾𐌰 𐍃𐌴𐌹𐌳𐍉𐍃',
'move'         => '𐌽𐌰𐌼𐌾𐌰𐌽 𐌰𐍆𐍄𐍂𐌰',
'movethispage' => '𐍃𐌺𐌹𐌿𐌱𐌰𐌽 𐍃𐌰 𐍃𐌴𐌹𐌳𐍉',

# Special:Log
'specialloguserlabel'  => 'Niutand:',
'speciallogtitlelabel' => 'Namo:',
'log'                  => '𐌻𐍉𐌲𐌱𐍉𐌺𐍉𐍃',
'all-logs-page'        => '𐌰𐌻𐌻𐌰 𐌻𐍉𐌲𐍉𐍃',

# Special:AllPages
'allpages'       => '𐌰𐌻𐌻𐌹𐍃 𐍃𐌴𐌹𐌳𐍉𐍃',
'alphaindexline' => '$1 du $2',
'nextpage'       => '𐌹𐍆𐍄𐌿𐌼𐌰 𐍃𐌴𐌹𐌳𐍉 ($1)',
'prevpage'       => '𐌰𐍆𐍄𐌿𐌼𐌰 𐍃𐌴𐌹𐌳𐍉 ($1)',
'allarticles'    => '𐌰𐌻𐌾𐌰 𐍃𐌴𐌹𐌳𐍉𐍃',
'allpagessubmit' => '𐌰𐍆𐌲𐌰𐌲𐌲𐌰𐌽',

# Special:Categories
'categories' => '𐌺𐌿𐌽𐌾𐍉𐍃',

# Special:LinkSearch
'linksearch-ns' => '𐍃𐌴𐌹𐌳𐍉𐍆𐌴𐍂𐌰:',

# E-mail user
'emailuser' => '𐍃𐌰𐌽𐌳𐌾𐌰𐌽 𐌸𐍉 𐌽𐌹𐌿𐍄𐌰𐌽𐌳 𐌱𐍉𐌺𐍉𐌼',

# Watchlist
'watchlist'         => '𐌼𐌴𐌹𐌽𐍉𐍃 𐍅𐌹𐍄𐌰𐌽𐌳𐍃𐌻𐌴𐌹𐍃𐍄𐌰',
'mywatchlist'       => '𐌼𐌴𐌹𐌽𐍉𐍃 𐍅𐌹𐍄𐌰𐌽𐌳𐍃𐌻𐌴𐌹𐍃𐍄𐌰',
'watch'             => '𐍅𐌰𐍂𐌰𐌽',
'watchthispage'     => '𐍅𐌰𐍂𐌰𐌽 𐍃𐌴𐌹𐌳𐍉',
'unwatch'           => '𐌽𐌹𐍅𐌰𐍂𐌰𐌽',
'watchlist-details' => '{{PLURAL:$1|$1 seido|$1 seidona}} witáiþs inu maþleiseidam.',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'Wita...',
'unwatching' => 'Niwita...',

'created' => '𐌲𐌰𐍃𐌺𐌰𐍀𐌾𐌰𐌽',

# Delete
'deletepage'            => '𐍄𐌰𐌹𐍂𐌰 𐍃𐌴𐌹𐌳𐍉',
'delete-legend'         => '𐍄𐌰𐌹𐍂𐌰𐌽',
'actioncomplete'        => '𐍅𐌰𐍃𐌿𐌷 𐌹𐍄𐌰 𐌲𐌰𐌿𐍃𐍄𐌹𐌿𐌷𐌰𐌽',
'dellogpage'            => '𐍄𐌰𐌹𐍂𐌰 𐌰𐌹𐍂𐍅𐌱𐍉𐌺𐌰',
'deleteotherreason'     => '𐌰𐌽𐌸𐌰𐍂/𐌼𐌰𐌹𐍃 𐌼𐌹𐍄𐍉𐌽𐍃:',
'deletereasonotherlist' => '𐌰𐌽𐌸𐌰𐍂 𐌼𐌹𐍄𐍉𐌽𐍃',

# Rollback
'rollbacklink' => '𐌰𐍆𐍅𐌰𐌻𐍅𐌾𐌰𐌽',

# Protect
'protectlogpage'      => 'Log af Baírgjan',
'prot_1movedto2'      => '[[$1]] skiubiþ du [[$2]]',
'protect-level-sysop' => '𐍃𐌴𐌹𐌳𐍉𐍆𐌰𐌸𐍃 𐌰𐌹𐌽𐌰𐌷𐌰',
'protect-expiring'    => 'bláuþiþ $1 (UTC)',
'restriction-type'    => 'Freihals:',

# Restrictions (nouns)
'restriction-edit' => '𐌼𐌰𐌹𐌳𐌾𐌰𐌽',
'restriction-move' => '𐍃𐌺𐌹𐌿𐌱𐌰𐌽',

# Undelete
'undeletebtn'            => '𐌰𐍆𐍄𐍂𐌰 𐌲𐌰𐌱𐍉𐍄𐌾𐌰𐌽',
'undelete-search-submit' => 'Sokeiþ',

# Namespace form on various pages
'namespace'      => '𐍃𐌴𐌹𐌳𐍉𐍆𐌴𐍂𐌰:',
'invert'         => 'Afwandjan kustus',
'blanknamespace' => '(𐍆𐍂𐌿𐌼𐌹𐍃𐍄𐍃)',

# Contributions
'contributions' => '𐌽𐌹𐌿𐍄𐌰𐌽𐌳𐌹𐍃 𐌰𐌹𐍅𐌻𐌰𐌲𐌹𐍉𐍃',
'mycontris'     => '𐌼𐌴𐌹𐌽𐍉𐍃 𐌰𐌹𐍅𐌻𐌰𐌲𐌹𐍉𐍃',
'contribsub2'   => '𐍆𐌰𐌿𐍂 $1 ($2)',
'uctop'         => '(háubiþ)',
'month'         => '𐍆𐍂𐌰𐌼 𐌼𐌴𐌽𐍉𐌸𐍃 (𐌾𐌰𐌷 𐌰𐍆𐍄𐌿𐌼𐌰):',
'year'          => '𐍆𐍂𐌰𐌼 𐌾𐌴𐍂𐌰 (𐌾𐌰𐌷 𐌰𐍆𐍄𐌿𐌼𐌰):',

'sp-contributions-newbies-sub' => 'Faúr niujis niutandis',
'sp-contributions-blocklog'    => 'Logboka af afdraúsjan',
'sp-contributions-talk'        => 'Maþleiseido',

# What links here
'whatlinkshere'       => '𐍈𐌰𐍂𐌾𐌹𐍃 𐍃𐌴𐌹𐌳𐍉𐌽𐌰 𐌷𐌻𐌰𐌲𐌺𐌾𐌰𐌽𐌳 𐌷𐌹𐌳𐍂𐌴',
'whatlinkshere-title' => 'Seidos hwarjis du $1 táiknjan',
'isredirect'          => '𐍄𐌰𐌹𐌺𐌾𐌰𐍃𐌴𐌹𐌳𐍉',
'istemplate'          => 'ináukan',
'whatlinkshere-prev'  => '{{PLURAL:$1|aftuma|aftumans $1}}',
'whatlinkshere-next'  => '{{PLURAL:$1|iftuma|iftumans $1}}',
'whatlinkshere-links' => '← táikajanbandja',

# Block/unblock
'blockip'            => '𐌰𐍆𐌳𐍂𐌰𐌿𐍃𐌾𐌰𐌽 𐌽𐌹𐌿𐍄𐌰𐌽𐌳𐌹𐍃',
'ipbreason'          => '𐍆𐌰𐌹𐍂𐌹𐌽𐌰:',
'ipbotheroption'     => 'anþar',
'ipblocklist-submit' => 'Sokeiþ',
'infiniteblock'      => 'ajukduþs',
'blocklink'          => '𐍅𐌰𐍂𐌲𐌾𐌰𐌽',
'unblocklink'        => '𐍅𐌰𐌽𐌳𐌾𐌰𐌽',
'contribslink'       => '𐌲𐌹𐌱𐍉𐍃',
'blocklogpage'       => '𐌻𐍉𐌲𐌱𐍉𐌺𐌰 𐌰𐍆 𐌰𐍆𐌳𐍂𐌰𐌿𐍃𐌾𐌰𐌽',
'blocklogentry'      => '𐌰𐍆𐌳𐍂𐌰𐌿𐍃𐌹𐌸 [[$1]] 𐍆𐌰𐌿𐍂 $2 $3',

# Move page
'movearticle' => '𐍃𐌺𐌹𐌿𐌱𐌰 𐍃𐌴𐌹𐌳𐍉:',
'newtitle'    => '𐌳𐌿 𐌽𐌹𐌿𐌾𐌹𐍃 𐌽𐌰𐌼𐍉𐍃:',
'move-watch'  => '𐍅𐌹𐍄𐌰𐌽 𐍃𐍉 𐍃𐌴𐌹𐌳𐍉',
'movepagebtn' => '𐍃𐌺𐌹𐌿𐌱𐌰 𐍃𐌴𐌹𐌳𐍉',
'movedto'     => 'skiubiþ du',
'movelogpage' => 'Log af skiubans',
'movereason'  => '𐍆𐌰𐌹𐍂𐌹𐌽𐌰:',
'revertmove'  => 'ráidjan',

# Thumbnails
'thumbnail-more' => 'Biáuknan',

# Tooltip help for the actions
'tooltip-pt-userpage'            => 'Meina niutandisseido',
'tooltip-pt-mytalk'              => 'Meina maþleiseido',
'tooltip-pt-preferences'         => 'Meinos brukjamaideineis',
'tooltip-pt-mycontris'           => 'Tala af meina gibom',
'tooltip-pt-logout'              => 'leiþan',
'tooltip-ca-protect'             => '𐌱𐌰𐌹𐍂𐌲𐌰 𐌸𐍉 𐍃𐌴𐌹𐌳𐍉',
'tooltip-ca-delete'              => '𐍄𐌰𐌹𐍂𐌰𐌽 𐍃𐍉 𐍃𐌴𐌹𐌳𐍉',
'tooltip-ca-move'                => 'Skiuban so seido',
'tooltip-search'                 => '𐍃𐍉𐌺𐌴𐌹𐌸 {{SITENAME}}',
'tooltip-p-logo'                 => 'Háubidaseido',
'tooltip-n-mainpage'             => '𐍃𐌰𐌹𐍈𐌰𐌽 𐍃𐌰 𐌷𐌰𐌿𐌱𐌹𐌳𐌰𐍃𐌴𐌹𐌳𐍉',
'tooltip-n-mainpage-description' => '𐍃𐌰𐌹𐍈𐌰𐌽 𐍃𐌰 𐌷𐌰𐌿𐌱𐌹𐌳𐌰𐍃𐌴𐌹𐌳𐍉',
'tooltip-t-upload'               => '𐌿𐍃𐌷𐌻𐌰𐌸𐌰𐌹𐌸 𐍆𐌴𐌹𐌻𐌰𐌽𐍃',
'tooltip-t-specialpages'         => 'Findiþ alla ussindseidos',
'tooltip-ca-nstab-user'          => '𐍃𐌰𐌹𐍈𐌰𐌽 𐍃𐌰 𐌽𐌹𐌿𐍄𐌰𐌽𐌳𐌹𐍃𐍃𐌴𐌹𐌳𐍉',
'tooltip-save'                   => 'Skreiban þein máideins',

# Browsing diffs
'previousdiff' => '← 𐌰𐍆𐍄𐌿𐌼𐌰 𐌰𐌹𐍂𐌹𐍃',
'nextdiff'     => 'Iftuma áiris →',

# Media information
'show-big-image' => 'Fullis wahstus',

# Special:NewFiles
'ilsubmit' => 'Sokeiþ',

# Metadata
'metadata' => 'Ufardata',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'allis',
'namespacesall' => 'allis',
'monthsall'     => '𐌰𐌻𐌻𐌹𐍃',

# Multipage image navigation
'imgmultigo' => 'Afgaggan!',

# Table pager
'table_pager_limit_submit' => 'Affgaggan',

# Special:Version
'version-other' => 'Anþar',

# Special:FilePath
'filepath-page' => 'Feilans:',

# Special:SpecialPages
'specialpages' => '𐌿𐍃𐍃𐌹𐌽𐌳𐍃𐌴𐌹𐌳𐍉𐍃',

);
